@@ -85,7 +85,7 @@ class DiscreteEnv(gym.Env):
     self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
     
     data = []
-    for self.state in self.state.itertuples(index=False):
+    for self.state in self.df.itertuples(index=False):
       Xs = self.state[0]
       Xa = self.state[1]
       Y = self.state[2]
